<?php

/**
 * @version     2.0.0
 * @package     com_jsonglyrics
 * @copyright   Copyright (C) 2014. All rights reserved.
 * @license     GNU General Public License version 2 or later; see LICENSE.txt
 * @author      John Kouvakis <john@kouvakis.gr> - http://www.kouvakis.gr
 */
// No direct access
defined('_JEXEC') or die;

jimport('joomla.application.component.view');

/**
 * View to edit
 */
class JsonglyricsViewSong extends JViewLegacy {

    protected $state;
    protected $item;
    protected $form;
    protected $params;

    /**
     * Display the view
     */
    public function display($tpl = null) {
        
		$app	= JFactory::getApplication();
        $user		= JFactory::getUser();
        
        $this->state = $this->get('State');
        $this->item = $this->get('Data');
        $this->params = $app->getParams('com_jsonglyrics');




        $song_need_tone = false;

         // Get the tone to change to from url
        $song_tone = (int)JRequest::getVar('jslyricstone', null, 'default', 'int');
        // Get the negative of the tone cause chord array is reversed
        $song_tone = -($song_tone);

        // We give the option +6 -6 tone variations. Everything else is 0.
        if (($song_tone > 6) || ($song_tone < -6)) { $song_tone = 0; }
        else if ($song_tone < 0) { $song_tone = 12 + $song_tone; }

        if (($song_tone > 0) || ($song_tone < 12)) {
            $song_need_tone = true;
        }
   		
		if ($song_need_tone) {
            $this->item->song = $this->transpose_song($song_tone,$this->item->song);
        }




        // Check for errors.
        if (count($errors = $this->get('Errors'))) {
            throw new Exception(implode("\n", $errors));
        }
        
        
        $this->_prepareDocument();

        parent::display($tpl);
    }


	/**
	 * Prepares the document
	 */
	protected function _prepareDocument() {
		$app	= JFactory::getApplication();
		$menus	= $app->getMenu();
		$title	= null;

		// Because the application sets a default page title,
		// we need to get it from the menu item itself
		$menu = $menus->getActive();
		if($menu)
		{
			$this->params->def('page_heading', $this->params->get('page_title', $menu->title));
		} else {
			$this->params->def('page_heading', JText::_('COM_JSONGLYRICS_DEFAULT_PAGE_TITLE'));
		}
		$title = $this->params->get('page_title', '');
		if (empty($title)) {
			$title = $app->getCfg('sitename');
		}
		elseif ($app->getCfg('sitename_pagetitles', 0) == 1) {
			$title = JText::sprintf('JPAGETITLE', $app->getCfg('sitename'), $title);
		}
		elseif ($app->getCfg('sitename_pagetitles', 0) == 2) {
			$title = JText::sprintf('JPAGETITLE', $title, $app->getCfg('sitename'));
		}
		$this->document->setTitle($title);

		if ($this->params->get('menu-meta_description'))
		{
			$this->document->setDescription($this->params->get('menu-meta_description'));
		}

		if ($this->params->get('menu-meta_keywords'))
		{
			$this->document->setMetadata('keywords', $this->params->get('menu-meta_keywords'));
		}

		if ($this->params->get('robots'))
		{
			$this->document->setMetadata('robots', $this->params->get('robots'));
		}
	}        

    function transpose_song($song_tone,$song_contents) {

        $song_array_tmp = explode("\n",$song_contents);

        for ($i=0;$i<count($song_array_tmp);$i++) {
            preg_match_all('/<p class=\"(.*?)\">(.*?)<\/p>/', $song_array_tmp[$i], $arr_tmp, PREG_SET_ORDER);
            if (count($arr_tmp) > 0) {
                $song_array[$i][0] = $arr_tmp[0][1];
                $song_array[$i][1] = $arr_tmp[0][2];
            }
        }

        $content = '';

        for($song_line=0;$song_line<count($song_array);$song_line++) {

            if($song_array[$song_line][0] == 'jsl_chords') {

                $chords_orig = array(); // Original Chords Array
                $chords_comb = array(); // Combination of Original=>Chords Array

                $len_chords_orig = ''; // Original Chords Line Length;
                $len_chords_repl = ''; // Original Chords Line Length;

                $str_chords_orig = ''; // Original Chords String
                $str_chords_repl = ''; // Replacement Chords String

                $chords_pattern = ''; // Chords Pattern String for Matching

                $pos_chords_orig = array(); // Original Chords Position Array
                $pos_chords_repl = array(); // Replacement Chords Position Array
                $pos_lyrics_spac = array(); // Positions of extra spaces for lyrics Array

                // Original Chords array. Reversed Ordered for smart strtr function.
                // We Need to change first the # chords.
                //$chords_orig = array( 'Â', "A#", "A", "G#", "G", "F#", "F", "E", "D#", "D", "C#", "C" );
                $chords_orig = array(   html_entity_decode('&#66;',ENT_NOQUOTES,'UTF-8'),
                                        html_entity_decode('&#65;',ENT_NOQUOTES,'UTF-8') . html_entity_decode('&#35;',ENT_NOQUOTES,'UTF-8'),
                                        html_entity_decode('&#65;',ENT_NOQUOTES,'UTF-8'),
                                        html_entity_decode('&#71;',ENT_NOQUOTES,'UTF-8') . html_entity_decode('&#35;',ENT_NOQUOTES,'UTF-8'),
                                        html_entity_decode('&#71;',ENT_NOQUOTES,'UTF-8'),
                                        html_entity_decode('&#70;',ENT_NOQUOTES,'UTF-8') . html_entity_decode('&#35;',ENT_NOQUOTES,'UTF-8'),
                                        html_entity_decode('&#70;',ENT_NOQUOTES,'UTF-8'),
                                        html_entity_decode('&#69;',ENT_NOQUOTES,'UTF-8'),
                                        html_entity_decode('&#68;',ENT_NOQUOTES,'UTF-8') . html_entity_decode('&#35;',ENT_NOQUOTES,'UTF-8'),
                                        html_entity_decode('&#68;',ENT_NOQUOTES,'UTF-8'),
                                        html_entity_decode('&#67;',ENT_NOQUOTES,'UTF-8') . html_entity_decode('&#35;',ENT_NOQUOTES,'UTF-8'),
                                        html_entity_decode('&#67;',ENT_NOQUOTES,'UTF-8')
                                    );

                //print_r($chords_orig);

                // Creation of the chords replacement array
                $j=0; $k=$song_tone;
                for ($i=0; $i< 12; $i++) {
                    if ($k == 12) { $k = 0; }
                    $chords_tmp[$j] = $chords_orig[$k];
                    $j++; $k++;
                }

                // Creation of the combination chords original/replacement array
                // This is for strtr function
                for($i=0;$i<12;$i++) {
                    $chords_comb[$chords_orig[$i]] = $chords_tmp[$i];
                }

                // Creation of the replacement array pattern
                $chords_repl_pattern = '/(';
                for ($i=0; $i<count($chords_tmp); $i++) {
                    $chords_repl_pattern .= $chords_tmp[$i] . 'm|';
                    $chords_repl_pattern .= $chords_tmp[$i] . '|';
                }
                $chords_repl_pattern = mb_substr($chords_repl_pattern,0,-1);
                $chords_repl_pattern .= ')/';

                $str_chords_orig = $song_array[$song_line][1];

                // Set initial length values for chord strings
                $len_chords_orig = mb_strlen($str_chords_orig);
                $len_chords_repl = $len_chords_orig;

                // Get all chords matches inside the string and the position of them
                $chords_pattern = '/(Bm|B|A#m|A#|Am|A|G#m|G#|Gm|G|F#m|F#|Fm|F|Em|E|D#m|D#|Dm|D|C#m|C#|Cm|C)/';
                preg_match_all($chords_pattern, $str_chords_orig, $pos_chords_orig, PREG_OFFSET_CAPTURE);
                $pos_chords_orig = $pos_chords_orig[0];


                // Creation of the replacement chords and position array
                for ($i=0; $i<count($pos_chords_orig); $i++) {
                    $string_tmp = $pos_chords_orig[$i][0];
                    $string_tmp = strtr($string_tmp,$chords_comb);
                    $pos_chords_repl[$i][0] = $string_tmp;
                    $pos_chords_repl[$i][1] = $pos_chords_orig[$i][1];
                }


                // Correction of replacement chords array and spaces array for lyrics
                $j=0; $k=0; $l=0;
                for ($i=0; $i<count($pos_chords_repl) - 1; $i++) {
                    if ($i < count($pos_chords_repl) - 1) {
                        if (mb_strlen($pos_chords_repl[$i][0]) > mb_strlen($pos_chords_orig[$i][0]) ) {
                            $j = $j + 1;
                            if ($pos_chords_orig[$i+1][1] == mb_strlen($pos_chords_orig[$i][0]) + $pos_chords_orig[$i][1]) {
                                $pos_lyrics_spac[$k] = $pos_chords_repl[$i][1] + mb_strlen($pos_chords_repl[$i][0]) - 1;
                                $k++;
                                //echo $i;
                            for ($l=$i+1; $l<count($pos_chords_repl); $l++) {
                                $pos_chords_repl[$l][1] = $pos_chords_repl[$l][1] + 1;
                            }
                            }
                        }
                    }
                }

                // Set length value for chord replacement string
                $len_chords_repl = $len_chords_repl + $j;

                // Creation of the replacement chords string
                $i=0;
                $j=0;
                $str_chords_repl = '';
                while ($i<$len_chords_repl) :
                    if (@$pos_chords_repl[$j][1] == $i) {
                        $str_chords_repl = $str_chords_repl . $pos_chords_repl[$j][0];
                        $i = $i + mb_strlen($pos_chords_repl[$j][0]);
                        $j++;
                    } else {
                        $str_chords_repl = $str_chords_repl . ' ';
                        $i++;
                    }
                endwhile;

                // convert spaces to special characters for reading
                $str_chords_repl = $this->convert_spaces_to_special($str_chords_repl);
                $str_chords_orig = $this->convert_spaces_to_special($str_chords_orig);

                $content[$song_line] = '<p class="jsl_chords">' . $str_chords_repl . '</p>';

            } elseif ($song_array[$song_line][0] == 'jsl_lyrics') {

                $i=0; $j=0; $k=0; $str_temp = '';
                if (!empty($pos_lyrics_spac)) {
                    while ($k < mb_strlen($song_array[$song_line][1])) {
                        if (@$pos_lyrics_spac[$j] == $i ) {
                            $str_temp .= html_entity_decode('&#45;',ENT_NOQUOTES,'UTF-8');
                            $j++;
                        } else {
                            $str_temp .= mb_substr($song_array[$song_line][1],$k,1);
                            $k++;
                        }
                        $i++;
                    }
                } else {
                    $str_temp = $song_array[$song_line][1];
                }

                $content[$song_line] = '<p class="' . $song_array[$song_line][0] . '">' . $str_temp . '</p>';

            } else {
                $content[$song_line] = '<p class="' . $song_array[$song_line][0] . '">' . $song_array[$song_line][1] . '</p>';
            }
        }
        $content = implode($content);
        //print_r($content);
        return $content;
    }

    function convert_spaces_to_special($str_var) {
    	$str_var2 = "";
        for($i=0; $i<mb_strlen($str_var); $i++) {
            if (mb_substr($str_var,$i,1) == html_entity_decode(' ',ENT_NOQUOTES,'UTF-8')) {
                $str_var2 .= html_entity_decode('&#160;',ENT_NOQUOTES,'UTF-8');
            } else {
                $str_var2 .= mb_substr($str_var,$i,1);
            }
        }
        return $str_var2;
    }    
}
